@@ -3,6 +3,7 @@ import subprocess
 import paramiko
 from log import log
 from func_timeout import func_set_timeout
+from func_timeout.exceptions import FunctionTimedOut
 from paramiko.ssh_exception import SSHException
 
 
@@ -90,9 +91,12 @@ class SSHClient(object):
             if not self.is_active():
                 raise RuntimeError("ssh transport is not active.")
             return self._exec(cmd,promt_response)
+        except FunctionTimedOut as e1:
+            log.error(f"when run cmd: {cmd}, meets exception.", exc_info=True)
+            return ExecResult(1, "", str(e1))
         except Exception as e:
             log.error(f"when run cmd: {cmd}, meets exception.", exc_info=True)
-            return ExecResult(255, "", str(e))
+            return ExecResult(1, "", str(e))
 
     @func_set_timeout(int(os.environ.get("SSH_SCP_TO_REMOTE_TIMEOUT", 120)))
     def _scp_to_remote(self, local_path, remote_path):
